@@ -87,7 +87,7 @@ void PasswordDialog::initializeUi()
             qCWarning(PLASMA_NM_KDED_LOG) << "list of secrets is empty!!!";
             m_hasError = true;
             m_error = SecretAgent::InternalError;
-            m_errorMessage = QLatin1String("No secrets were requested");
+            m_errorMessage = i18nc("@info:status 'secrets' means the authentication needed for a VPN", "No secrets were requested");
             return;
         }
 
@@ -95,9 +95,17 @@ void PasswordDialog::initializeUi()
         Setting::SettingType connectionType = setting->type();
         if (wifi && (connectionType == Setting::WirelessSecurity || connectionType == Setting::Security8021x)) {
             const QString ssid = QString::fromUtf8(wifi->ssid());
-            m_ui->labelText->setText(i18n("Provide the password for the wireless network '%1':", ssid));
+            if (m_flags & NetworkManager::SecretAgent::RequestNew) {
+                m_ui->labelText->setText(i18n("Incorrect password for the wireless network \"%1\". Please try again.", ssid));
+            } else {
+                m_ui->labelText->setText(i18n("Enter the password for the wireless network \"%1\":", ssid));
+            }
         } else {
-            m_ui->labelText->setText(i18n("Provide the password for the connection '%1':", m_connectionSettings->id()));
+            if (m_flags & NetworkManager::SecretAgent::RequestNew) {
+                m_ui->labelText->setText(i18n("Incorrect password for the connection \"%1\". Please try again.", m_connectionSettings->id()));
+            } else {
+                m_ui->labelText->setText(i18n("Enter the password for the connection \"%1\":", m_connectionSettings->id()));
+            }
         }
 
         QString connectionLabel;
@@ -110,7 +118,7 @@ void PasswordDialog::initializeUi()
             qCWarning(PLASMA_NM_KDED_LOG) << "Missing VPN setting!";
             m_hasError = true;
             m_error = SecretAgent::InternalError;
-            m_errorMessage = QLatin1String("VPN settings are missing");
+            m_errorMessage = i18nc("@info:status", "VPN settings are missing");
         } else {
             const QString serviceType = vpnSetting->serviceType();
             const auto result = VpnUiPlugin::loadPluginForType(this, serviceType);
@@ -123,7 +131,7 @@ void PasswordDialog::initializeUi()
                 auto layout = new QVBoxLayout();
                 layout->addWidget(m_vpnWidget);
                 m_ui->vpnWidget->setLayout(layout);
-                m_ui->labelText->setText(i18n("Provide the secrets for the VPN connection '%1':", m_connectionSettings->id()));
+                m_ui->labelText->setText(i18n("Provide the secrets for the VPN connection \"%1\":", m_connectionSettings->id()));
                 setWindowTitle(i18n("VPN secrets (%1) dialog", shortName));
 
                 // Hide generic password field and OK button in case of openconnect dialog
