@@ -21,8 +21,17 @@ class L2tpIpsecWidget : public QDialog
 {
     Q_OBJECT
 
-    enum AuthType { PSK = 0, TLS };
-    enum IpsecDaemonType { NoIpsecDaemon, Libreswan, Strongswan, Openswan, UnknownIpsecDaemon };
+    enum AuthType {
+        PSK = 0,
+        TLS
+    };
+    enum IpsecDaemonType {
+        NoIpsecDaemon,
+        Libreswan,
+        Strongswan,
+        Openswan,
+        UnknownIpsecDaemon
+    };
 
 public:
     explicit L2tpIpsecWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
